@@ -1,7 +1,7 @@
 package Locale::Country::Extra;
 use strict; use warnings;
 
-our $VERSION = '0.090_1';
+our $VERSION = '0.05';
 
 use Locale::Country qw();
 use Locale::Country::Multilingual { use_io_layer => 1 };
@@ -20,6 +20,7 @@ sub new {
 
 sub country_from_code {
     my ( $self, $code ) = @_;
+    die "code is required" if !$code;
     $code = lc $code;
 
     # we need gb
@@ -30,6 +31,7 @@ sub country_from_code {
 
 sub code_from_country {
     my ( $self, $country ) = @_;
+    die "country is required" if !$country;
 
     my %code_countries = reverse %{ $self->_country_codes };
     return lc $code_countries{$country};
@@ -37,6 +39,7 @@ sub code_from_country {
 
 sub idd_from_code {
     my ( $self, $code ) = @_;
+    die "code is required" if !$code;
     $code = lc $code;
 
     # we need gb
@@ -47,6 +50,7 @@ sub idd_from_code {
 
 sub code_from_phone {
     my ( $self, $number ) = @_;
+    die "number is required" if !$number;
 
     $number =~ s/\D//g;    # Remove non-digits
     $number =~ s/^00//;    # Remove the leading '00'.
@@ -66,12 +70,6 @@ sub code_from_phone {
     return '';
 }
 
-sub all_country_names {
-    my $self = shift;
-    return values %{ $self->_country_codes };
-}
-
-
 sub all_country_codes {
     my $self = shift;
     return keys %{ $self->_country_codes };
@@ -79,6 +77,8 @@ sub all_country_codes {
 
 sub localized_code2country {
     my ( $self, $country_code, $lang ) = @_;
+    die "country_code is required" if !$country_code;
+    die "lang is required"         if !$lang;
 
     my $lcm = Locale::Country::Multilingual->new();
     return $lcm->code2country( $country_code, $lang );
@@ -356,7 +356,7 @@ Locale::Country::Extra - Standard and IDD codes for Country identification, with
 
 =head1 VERSION
 
-Version 0.09
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -365,7 +365,7 @@ Version 0.09
     my $countries = Locale::Country::Extra->new();
 
     my $c = $countries->country_from_code('au'); # returns 'Australia'
-    my $code = $countries->code_from_country('Indonesia'); # returns 'id'
+    my $code = $countries->code_from_phone('Indonesia'); # returns 'id'
     my $idd = $countries->idd_from_code('in'); # returns 91
     my $code = $countries->code_from_phone('+44 8882220202'); # returns 'gb'
 
@@ -381,16 +381,6 @@ Version 0.09
 
 =cut
 
-=head2 all_country_names
-
-    USAGE
-    my @names = $c->all_country_names()
-
-    RETURNS
-    A list of all country names
-
-=cut
-
 =head2 code_from_country
 
     USAGE
@@ -410,7 +400,7 @@ Version 0.09
     my $code = $c->code_from_phone($phone_number)
 
     PARAMS
-    $phone_number   => Phone Number
+    $phone_number   => Phone Numbder
 
     RETURNS
     Country code
@@ -469,7 +459,7 @@ Version 0.09
 
 =head1 SOURCE CODE
 
-L<GitHub|https://github.com/binary-com/perl-Locale-Country-Extra>
+L<Github|https://github.com/binary-com/perl-Locale-Country-Extra>
 
 =head1 AUTHOR
 
